@@ -25,7 +25,7 @@ from behave.step_registry import registry
 from behavex.conf_mgr import get_env, get_param
 from behavex.global_vars import global_vars
 from behavex.outputs.report_utils import (get_environment_details,
-                                          get_error_message,
+                                          get_error_message, get_string_hash,
                                           match_for_execution, text)
 from behavex.utils import (generate_hash, generate_uuid, get_scenario_tags,
                            retry_file_operation)
@@ -41,6 +41,11 @@ def add_step_info_background(step, parent_node):
     for attrib in ('step_type', 'name', 'text', 'status'):
         step_info[attrib] = text(getattr(step, attrib))
     step_info['duration'] = step.duration or 0
+    # Add start and stop times if they exist
+    if hasattr(step, 'start'):
+        step_info['start'] = getattr(step, 'start')
+    if hasattr(step, 'stop'):
+        step_info['stop'] = getattr(step, 'stop')
     if step.table:
         step_info['table'] = {}
         for heading in step.table.headings:
@@ -168,10 +173,20 @@ def _processing_scenarios(scenarios, scenario_list, id_feature):
             scenario_info['name'] = getattr(scenario, 'name')
             scenario_info['duration'] = getattr(scenario, 'duration')
             scenario_info['status'] = getattr(scenario, 'status').name
+            # Add start and stop times if they exist
+            if hasattr(scenario, 'start'):
+                scenario_info['start'] = getattr(scenario, 'start')
+            if hasattr(scenario, 'stop'):
+                scenario_info['stop'] = getattr(scenario, 'stop')
             scenario_info['tags'] = getattr(scenario, 'effective_tags')
             scenario_info['filename'] = text(scenario.filename)
             scenario_info['feature'] = scenario.feature.name
             scenario_info['id_feature'] = id_feature
+
+            # Extract parameters for scenario outlines
+            if hasattr(scenario, '_row') and scenario._row:
+                scenario_info['parameters'] = dict(zip(scenario._row.headings, scenario._row.cells))
+
             steps = []
             for step in scenario.steps:
                 add_step_info(step, steps)
@@ -186,6 +201,9 @@ def _processing_scenarios(scenarios, scenario_list, id_feature):
             scenario_info['error_step'] = error_step
             scenario_info['error_background'] = error_background
             scenario_info['id_hash'] = generate_uuid()
+            scenario_info['identifier_hash'] = scenario.identifier_hash if hasattr(scenario, 'identifier_hash') else get_string_hash(f"{str(scenario.feature.filename)}-{str(scenario.line)}")
+            scenario_info['process_id'] = str(scenario.process_id) if hasattr(scenario, 'process_id') else str(os.getpid())
+            scenario_info['worker_id'] = str(scenario.worker_id) if hasattr(scenario, 'worker_id') else str(os.getpid())
             if scenario.feature.name in global_vars.retried_scenarios:
                 if (
                     scenario.name
@@ -241,10 +259,28 @@ def _step_to_dict(index, step):
         step_info['duration'] = step.duration or 0.0
     else:
         step_info['duration'] = 0.0
+    if hasattr(step, 'line'):
+        step_info['line'] = getattr(step, 'line')
+    # Add start and stop times if they exist
+    if hasattr(step, 'start'):
+        step_info['start'] = getattr(step, 'start')
+    if hasattr(step, 'stop'):
+        step_info['stop'] = getattr(step, 'stop')
     if step.exception:
         # step.exception is forced to be a str type variable
         step_info['error_msg'] = get_error_message(str(step.exception))
-        step_info['error_lines'] = traceback.format_tb(step.exc_traceback)
+        # Handle traceback formatting safely
+        try:
+            # Check if exception has a traceback attribute
+            if hasattr(step.exception, '__traceback__'):
+                step_info['error_lines'] = traceback.format_exception(
+                    type(step.exception), step.exception, step.exception.__traceback__)
+            else:
+                # Fallback for older Python versions or exceptions without traceback
+                step_info['error_lines'] = traceback.format_exc().splitlines()
+        except Exception:
+            # Provide a safe fallback if traceback extraction fails
+            step_info['error_lines'] = get_error_message(str(step.exception))
     if step.table:
         step_info['table'] = {}
         for heading in step.table.headings:
