@@ -10,13 +10,22 @@ root_project_path = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'
 tests_features_path = os.path.join(root_project_path, 'tests', 'features')
 test_images_path = os.path.join(root_project_path, 'tests', 'test_images')
 
-# Import behavex-images functionality
+# Import behavex-images functionality - fail if required
+def get_image_attachments_module():
+    """Get the image_attachments module, raising an error if not available."""
+    try:
+        from behavex_images import image_attachments
+        return image_attachments
+    except (ImportError, ModuleNotFoundError) as e:
+        raise AssertionError(f"behavex-images is required for image attachment tests but not available: {e}")
+
+# Check if behavex-images is available for optional usage
 try:
     from behavex_images import image_attachments
     behavex_images_available = True
-except ImportError:
+except (ImportError, ModuleNotFoundError) as e:
     behavex_images_available = False
-    logging.warning("behavex-images not available, image attachment tests will be skipped")
+    logging.warning(f"behavex-images not available, image attachment tests will be skipped: {e}")
 
 
 @given('The progress bar is enabled')
@@ -190,6 +199,9 @@ def step_impl(context):
         assert message not in context.result.stdout.lower(), f"Unexpected output when checking exception messages in the console output: {context.result.stdout}\n"
 
 
+
+
+
 @then('I should see the same number of scenarios in the reports and the console output')
 def step_impl(context):
     total_scenarios_in_html_report = get_total_scenarios_in_html_report(context)
@@ -307,19 +319,24 @@ def get_total_scenarios_in_junit_reports(context, consider_skipped_scenarios=Tru
 @given('I take a screenshot using test image {image_number}')
 def step_take_screenshot_using_test_image(context, image_number):
     """Attach a test image file using behavex-images"""
-    if not behavex_images_available:
-        logging.warning("behavex-images not available, skipping image attachment")
-        return
-
-    # Import here to avoid issues if behavex-images is not available
-    from behavex_images import image_attachments
-
     image_path = os.path.join(test_images_path, f'test_image_{image_number}.png')
-    if os.path.exists(image_path):
+    if not os.path.exists(image_path):
+        raise FileNotFoundError(f"Test image not found: {image_path}")
+
+    # Check if image attachments are required for this test
+    if hasattr(context, 'require_image_attachments') and context.require_image_attachments:
+        image_attachments = get_image_attachments_module()
         image_attachments.attach_image_file(context, image_path)
         logging.info(f"Attached test image: {image_path}")
     else:
-        raise FileNotFoundError(f"Test image not found: {image_path}")
+        # Optional usage - skip if not available
+        if not behavex_images_available:
+            logging.warning("behavex-images not available, skipping image attachment")
+            return
+        # Import here to avoid issues if behavex-images is not available
+        from behavex_images import image_attachments
+        image_attachments.attach_image_file(context, image_path)
+        logging.info(f"Attached test image: {image_path}")
 
 
 @when('I run the behavex command with image attachments')
